% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/coordinates.R
\name{coordinates}
\alias{coordinates}
\alias{coord}
\alias{alr_c}
\alias{clr_c}
\alias{ilr_c}
\alias{olr_c}
\title{Get coordinates from compositions w.r.t. an specific basis}
\usage{
coordinates(X, basis = "ilr")

coord(..., basis = "ilr")

alr_c(X)

clr_c(X)

ilr_c(X)

olr_c(X)
}
\arguments{
\item{X}{compositional dataset. Either a matrix, a data.frame or a vector}

\item{basis}{basis used to calculate the coordinates. \code{basis} can be either a string or a matrix.
Accepted values for strings are: 'ilr' (default), 'clr', 'alr', 'pw', 'pc', 'pb' and 'cdp'. If \code{basis} is a matrix, it is expected
to have log-ratio basis given in columns.}

\item{...}{components of the compositional data}
}
\value{
Coordinates of composition \code{X} with respect the given \code{basis}.
}
\description{
Calculate the coordinates of a composition with respect a given basis
}
\details{
\code{coordinates} function calculates the coordinates of a compositiona w.r.t. a given basis. `basis` parameter is
used to set the basis, it can be either a matrix defining the log-contrasts in columns or a string defining some well-known
log-contrast: 'alr' 'clr', 'ilr', 'pw', 'pc', 'pb' and 'cdp', for the additive log-ratio, centered log-ratio, isometric log-ratio,
pairwise log-ratio, clr principal components, clr principal balances or default's CoDaPack balances respectively.
}
\examples{
# Default ilr given by ilr_basis(5) is given
coordinates(1:5)
B = ilr_basis(5)
coordinates(1:5, B)
}
\seealso{
See functions \code{\link{ilr_basis}}, \code{\link{alr_basis}},
\code{\link{clr_basis}}, \code{\link{sbp_basis}}
to define different compositional basis.
See function \code{\link{composition}} to obtain details on how to calculate
a compositions from given coordinates.
}
